@@ -26,38 +26,34 @@
 #include "uint-bset.h"
 #include "uint-spbset.h"
 
-/* The last 2 #include files should be in this order */
-#include "curl_memory.h"
-#include "memdebug.h"
-
 #ifdef DEBUGBUILD
-#define CURL_UINT_SPBSET_MAGIC  0x70737362
+#define CURL_UINT32_SPBSET_MAGIC  0x70737362
 #endif
 
 /* Clear the bitset, making it empty. */
-UNITTEST void Curl_uint_spbset_clear(struct uint_spbset *bset);
+UNITTEST void Curl_uint32_spbset_clear(struct uint32_spbset *bset);
 
-void Curl_uint_spbset_init(struct uint_spbset *bset)
+void Curl_uint32_spbset_init(struct uint32_spbset *bset)
 {
   memset(bset, 0, sizeof(*bset));
 #ifdef DEBUGBUILD
-  bset->init = CURL_UINT_SPBSET_MAGIC;
+  bset->init = CURL_UINT32_SPBSET_MAGIC;
 #endif
 }
 
-void Curl_uint_spbset_destroy(struct uint_spbset *bset)
+void Curl_uint32_spbset_destroy(struct uint32_spbset *bset)
 {
-  DEBUGASSERT(bset->init == CURL_UINT_SPBSET_MAGIC);
-  Curl_uint_spbset_clear(bset);
+  DEBUGASSERT(bset->init == CURL_UINT32_SPBSET_MAGIC);
+  Curl_uint32_spbset_clear(bset);
 }
 
-unsigned int Curl_uint_spbset_count(struct uint_spbset *bset)
+uint32_t Curl_uint32_spbset_count(struct uint32_spbset *bset)
 {
-  struct uint_spbset_chunk *chunk;
-  unsigned int i, n = 0;
+  struct uint32_spbset_chunk *chunk;
+  uint32_t i, n = 0;
 
   for(chunk = &bset->head; chunk; chunk = chunk->next) {
-    for(i = 0; i < CURL_UINT_SPBSET_CH_SLOTS; ++i) {
+    for(i = 0; i < CURL_UINT32_SPBSET_CH_SLOTS; ++i) {
       if(chunk->slots[i])
         n += CURL_POPCOUNT64(chunk->slots[i]);
     }
@@ -65,13 +61,13 @@ unsigned int Curl_uint_spbset_count(struct uint_spbset *bset)
   return n;
 }
 
-bool Curl_uint_spbset_empty(struct uint_spbset *bset)
+bool Curl_uint32_spbset_empty(struct uint32_spbset *bset)
 {
-  struct uint_spbset_chunk *chunk;
-  unsigned int i;
+  struct uint32_spbset_chunk *chunk;
+  uint32_t i;
 
   for(chunk = &bset->head; chunk; chunk = chunk->next) {
-    for(i = 0; i < CURL_UINT_SPBSET_CH_SLOTS; ++i) {
+    for(i = 0; i < CURL_UINT32_SPBSET_CH_SLOTS; ++i) {
       if(chunk->slots[i])
         return FALSE;
     }
@@ -79,23 +75,22 @@ bool Curl_uint_spbset_empty(struct uint_spbset *bset)
   return TRUE;
 }
 
-UNITTEST void Curl_uint_spbset_clear(struct uint_spbset *bset)
+UNITTEST void Curl_uint32_spbset_clear(struct uint32_spbset *bset)
 {
-  struct uint_spbset_chunk *next, *chunk;
+  struct uint32_spbset_chunk *next, *chunk;
 
   for(chunk = bset->head.next; chunk; chunk = next) {
     next = chunk->next;
-    free(chunk);
+    curlx_free(chunk);
   }
   memset(&bset->head, 0, sizeof(bset->head));
 }
 
-
-static struct uint_spbset_chunk *
-uint_spbset_get_chunk(struct uint_spbset *bset, unsigned int i, bool grow)
+static struct uint32_spbset_chunk *
+uint32_spbset_get_chunk(struct uint32_spbset *bset, uint32_t i, bool grow)
 {
-  struct uint_spbset_chunk *chunk, **panchor = NULL;
-  unsigned int i_offset = (i & ~CURL_UINT_SPBSET_CH_MASK);
+  struct uint32_spbset_chunk *chunk, **panchor = NULL;
+  uint32_t i_offset = (i & ~CURL_UINT32_SPBSET_CH_MASK);
 
   if(!bset)
     return NULL;
@@ -116,7 +111,7 @@ uint_spbset_get_chunk(struct uint_spbset *bset, unsigned int i, bool grow)
     return NULL;
 
   /* need a new one */
-  chunk = calloc(1, sizeof(*chunk));
+  chunk = curlx_calloc(1, sizeof(*chunk));
   if(!chunk)
     return NULL;
 
@@ -133,62 +128,59 @@ uint_spbset_get_chunk(struct uint_spbset *bset, unsigned int i, bool grow)
   return chunk;
 }
 
-
-bool Curl_uint_spbset_add(struct uint_spbset *bset, unsigned int i)
+bool Curl_uint32_spbset_add(struct uint32_spbset *bset, uint32_t i)
 {
-  struct uint_spbset_chunk *chunk;
-  unsigned int i_chunk;
+  struct uint32_spbset_chunk *chunk;
+  uint32_t i_chunk;
 
-  chunk = uint_spbset_get_chunk(bset, i, TRUE);
+  chunk = uint32_spbset_get_chunk(bset, i, TRUE);
   if(!chunk)
     return FALSE;
 
   DEBUGASSERT(i >= chunk->offset);
   i_chunk = (i - chunk->offset);
-  DEBUGASSERT((i_chunk / 64) < CURL_UINT_SPBSET_CH_SLOTS);
-  chunk->slots[(i_chunk / 64)] |= ((curl_uint64_t)1 << (i_chunk % 64));
+  DEBUGASSERT((i_chunk / 64) < CURL_UINT32_SPBSET_CH_SLOTS);
+  chunk->slots[(i_chunk / 64)] |= ((uint64_t)1 << (i_chunk % 64));
   return TRUE;
 }
 
-
-void Curl_uint_spbset_remove(struct uint_spbset *bset, unsigned int i)
+void Curl_uint32_spbset_remove(struct uint32_spbset *bset, uint32_t i)
 {
-  struct uint_spbset_chunk *chunk;
-  unsigned int i_chunk;
+  struct uint32_spbset_chunk *chunk;
+  uint32_t i_chunk;
 
-  chunk = uint_spbset_get_chunk(bset, i, FALSE);
+  chunk = uint32_spbset_get_chunk(bset, i, FALSE);
   if(chunk) {
     DEBUGASSERT(i >= chunk->offset);
     i_chunk = (i - chunk->offset);
-    DEBUGASSERT((i_chunk / 64) < CURL_UINT_SPBSET_CH_SLOTS);
-    chunk->slots[(i_chunk / 64)] &= ~((curl_uint64_t)1 << (i_chunk % 64));
+    DEBUGASSERT((i_chunk / 64) < CURL_UINT32_SPBSET_CH_SLOTS);
+    chunk->slots[(i_chunk / 64)] &= ~((uint64_t)1 << (i_chunk % 64));
   }
 }
 
-
-bool Curl_uint_spbset_contains(struct uint_spbset *bset, unsigned int i)
+bool Curl_uint32_spbset_contains(struct uint32_spbset *bset, uint32_t i)
 {
-  struct uint_spbset_chunk *chunk;
-  unsigned int i_chunk;
+  struct uint32_spbset_chunk *chunk;
+  uint32_t i_chunk;
 
-  chunk = uint_spbset_get_chunk(bset, i, FALSE);
+  chunk = uint32_spbset_get_chunk(bset, i, FALSE);
   if(chunk) {
     DEBUGASSERT(i >= chunk->offset);
     i_chunk = (i - chunk->offset);
-    DEBUGASSERT((i_chunk / 64) < CURL_UINT_SPBSET_CH_SLOTS);
+    DEBUGASSERT((i_chunk / 64) < CURL_UINT32_SPBSET_CH_SLOTS);
     return (chunk->slots[i_chunk / 64] &
-            ((curl_uint64_t)1 << (i_chunk % 64))) != 0;
+            ((uint64_t)1 << (i_chunk % 64))) != 0;
   }
   return FALSE;
 }
 
-bool Curl_uint_spbset_first(struct uint_spbset *bset, unsigned int *pfirst)
+bool Curl_uint32_spbset_first(struct uint32_spbset *bset, uint32_t *pfirst)
 {
-  struct uint_spbset_chunk *chunk;
-  unsigned int i;
+  struct uint32_spbset_chunk *chunk;
+  uint32_t i;
 
   for(chunk = &bset->head; chunk; chunk = chunk->next) {
-    for(i = 0; i < CURL_UINT_SPBSET_CH_SLOTS; ++i) {
+    for(i = 0; i < CURL_UINT32_SPBSET_CH_SLOTS; ++i) {
       if(chunk->slots[i]) {
         *pfirst = chunk->offset + ((i * 64) + CURL_CTZ64(chunk->slots[i]));
         return TRUE;
@@ -199,30 +191,28 @@ bool Curl_uint_spbset_first(struct uint_spbset *bset, unsigned int *pfirst)
   return FALSE;
 }
 
-
-static bool uint_spbset_chunk_first(struct uint_spbset_chunk *chunk,
-                                    unsigned int *pfirst)
+static bool uint32_spbset_chunk_first(struct uint32_spbset_chunk *chunk,
+                                      uint32_t *pfirst)
 {
-  unsigned int i;
-  for(i = 0; i < CURL_UINT_SPBSET_CH_SLOTS; ++i) {
+  uint32_t i;
+  for(i = 0; i < CURL_UINT32_SPBSET_CH_SLOTS; ++i) {
     if(chunk->slots[i]) {
       *pfirst = chunk->offset + ((i * 64) + CURL_CTZ64(chunk->slots[i]));
       return TRUE;
     }
   }
-  *pfirst = UINT_MAX; /* a value we cannot store */
+  *pfirst = UINT32_MAX; /* a value we cannot store */
   return FALSE;
 }
 
-
-static bool uint_spbset_chunk_next(struct uint_spbset_chunk *chunk,
-                                   unsigned int last,
-                                   unsigned int *pnext)
+static bool uint32_spbset_chunk_next(struct uint32_spbset_chunk *chunk,
+                                     uint32_t last,
+                                     uint32_t *pnext)
 {
   if(chunk->offset <= last) {
-    curl_uint64_t x;
-    unsigned int i = ((last - chunk->offset) / 64);
-    if(i < CURL_UINT_SPBSET_CH_SLOTS) {
+    uint64_t x;
+    uint32_t i = ((last - chunk->offset) / 64);
+    if(i < CURL_UINT32_SPBSET_CH_SLOTS) {
       x = (chunk->slots[i] >> (last % 64));
       if(x) {
         /* more bits set, next is `last` + trailing0s of the shifted slot */
@@ -230,7 +220,7 @@ static bool uint_spbset_chunk_next(struct uint_spbset_chunk *chunk,
         return TRUE;
       }
       /* no more bits set in the last slot, scan forward */
-      for(i = i + 1; i < CURL_UINT_SPBSET_CH_SLOTS; ++i) {
+      for(i = i + 1; i < CURL_UINT32_SPBSET_CH_SLOTS; ++i) {
         if(chunk->slots[i]) {
           *pnext = chunk->offset + ((i * 64) + CURL_CTZ64(chunk->slots[i]));
           return TRUE;
@@ -238,18 +228,18 @@ static bool uint_spbset_chunk_next(struct uint_spbset_chunk *chunk,
       }
     }
   }
-  *pnext = UINT_MAX;
+  *pnext = UINT32_MAX;
   return FALSE;
 }
 
-bool Curl_uint_spbset_next(struct uint_spbset *bset, unsigned int last,
-                           unsigned int *pnext)
+bool Curl_uint32_spbset_next(struct uint32_spbset *bset, uint32_t last,
+                             uint32_t *pnext)
 {
-  struct uint_spbset_chunk *chunk;
-  unsigned int last_offset;
+  struct uint32_spbset_chunk *chunk;
+  uint32_t last_offset;
 
   ++last; /* look for the next higher number */
-  last_offset = (last & ~CURL_UINT_SPBSET_CH_MASK);
+  last_offset = (last & ~CURL_UINT32_SPBSET_CH_MASK);
 
   for(chunk = &bset->head; chunk; chunk = chunk->next) {
     if(chunk->offset >= last_offset) {
@@ -259,17 +249,17 @@ bool Curl_uint_spbset_next(struct uint_spbset *bset, unsigned int last,
 
   if(chunk && (chunk->offset == last_offset)) {
     /* is there a number higher than last in this chunk? */
-    if(uint_spbset_chunk_next(chunk, last, pnext))
+    if(uint32_spbset_chunk_next(chunk, last, pnext))
       return TRUE;
     /* not in this chunk */
     chunk = chunk->next;
   }
   /* look for the first in the "higher" chunks, if there are any. */
   while(chunk) {
-    if(uint_spbset_chunk_first(chunk, pnext))
+    if(uint32_spbset_chunk_first(chunk, pnext))
       return TRUE;
     chunk = chunk->next;
   }
-  *pnext = UINT_MAX;
+  *pnext = UINT32_MAX;
   return FALSE;
 }
