@@ -24,25 +24,23 @@
 #include "first.h"
 
 #include "testtrace.h"
-#include "memdebug.h"
 
-static CURLcode test_lib2502(char *URL)
+static CURLcode test_lib2502(const char *URL)
 {
   CURLcode res = CURLE_OK;
   CURL *curl[NUM_HANDLES] = {0};
   int running;
-  CURLM *m = NULL;
+  CURLM *multi = NULL;
   size_t i;
   char target_url[256];
   char dnsentry[256];
   struct curl_slist *slist = NULL;
-  char *port = libtest_arg3;
-  char *address = libtest_arg2;
+  const char *port = libtest_arg3;
+  const char *address = libtest_arg2;
 
   (void)URL;
 
-  curl_msnprintf(dnsentry, sizeof(dnsentry), "localhost:%s:%s",
-                 port, address);
+  curl_msnprintf(dnsentry, sizeof(dnsentry), "localhost:%s:%s", port, address);
   curl_mprintf("%s\n", dnsentry);
   slist = curl_slist_append(slist, dnsentry);
   if(!slist) {
@@ -54,9 +52,9 @@ static CURLcode test_lib2502(char *URL)
 
   global_init(CURL_GLOBAL_ALL);
 
-  multi_init(m);
+  multi_init(multi);
 
-  multi_setopt(m, CURLMOPT_MAXCONNECTS, 1L);
+  multi_setopt(multi, CURLMOPT_MAXCONNECTS, 1L);
 
   /* get each easy handle */
   for(i = 0; i < CURL_ARRAYSIZE(curl); i++) {
@@ -64,20 +62,19 @@ static CURLcode test_lib2502(char *URL)
     easy_init(curl[i]);
     /* specify target */
     curl_msnprintf(target_url, sizeof(target_url),
-                   "https://localhost:%s/path/2502%04i",
-                   port, (int)i + 1);
+                   "https://localhost:%s/path/2502%04zu", port, i + 1);
     target_url[sizeof(target_url) - 1] = '\0';
     easy_setopt(curl[i], CURLOPT_URL, target_url);
     /* go http2 */
     easy_setopt(curl[i], CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_3ONLY);
-    easy_setopt(curl[i], CURLOPT_CONNECTTIMEOUT_MS, (long)5000);
+    easy_setopt(curl[i], CURLOPT_CONNECTTIMEOUT_MS, 5000L);
     easy_setopt(curl[i], CURLOPT_CAINFO, libtest_arg4);
     /* wait for first connection established to see if we can share it */
     easy_setopt(curl[i], CURLOPT_PIPEWAIT, 1L);
     /* go verbose */
-    libtest_debug_config.nohex = 1;
-    libtest_debug_config.tracetime = 0;
-    test_setopt(curl[i], CURLOPT_DEBUGDATA, &libtest_debug_config);
+    debug_config.nohex = TRUE;
+    debug_config.tracetime = FALSE;
+    test_setopt(curl[i], CURLOPT_DEBUGDATA, &debug_config);
     easy_setopt(curl[i], CURLOPT_DEBUGFUNCTION, libtest_debug_cb);
     easy_setopt(curl[i], CURLOPT_VERBOSE, 1L);
     /* include headers */
@@ -90,7 +87,7 @@ static CURLcode test_lib2502(char *URL)
 
   for(i = 0; i < CURL_ARRAYSIZE(curl); i++) {
     /* add handle to multi */
-    multi_add_handle(m, curl[i]);
+    multi_add_handle(multi, curl[i]);
 
     for(;;) {
       struct timeval interval;
@@ -100,7 +97,7 @@ static CURLcode test_lib2502(char *URL)
       interval.tv_sec = 1;
       interval.tv_usec = 0;
 
-      multi_perform(m, &running);
+      multi_perform(multi, &running);
 
       abort_on_test_timeout();
 
@@ -111,7 +108,7 @@ static CURLcode test_lib2502(char *URL)
       FD_ZERO(&wr);
       FD_ZERO(&exc);
 
-      multi_fdset(m, &rd, &wr, &exc, &maxfd);
+      multi_fdset(multi, &rd, &wr, &exc, &maxfd);
 
       /* At this point, maxfd is guaranteed to be greater or equal than -1. */
 
@@ -127,13 +124,13 @@ test_cleanup:
   /* proper cleanup sequence - type PB */
 
   for(i = 0; i < CURL_ARRAYSIZE(curl); i++) {
-    curl_multi_remove_handle(m, curl[i]);
+    curl_multi_remove_handle(multi, curl[i]);
     curl_easy_cleanup(curl[i]);
   }
 
   curl_slist_free_all(slist);
 
-  curl_multi_cleanup(m);
+  curl_multi_cleanup(multi);
   curl_global_cleanup();
 
   return res;
