@@ -91,9 +91,18 @@ static CURLcode test_unit1398(const char *arg)
   fail_unless(rc == 15, "return code should be 15");
   fail_unless(!strcmp(output, "    1234    567"), "wrong output");
 
+#if defined(__clang__) && \
+  (__clang_major__ > 3 || (__clang_major__ == 3 && __clang_minor__ >= 1))
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wformat-non-iso"
+#endif
   /* double precision */
   rc = curl_msnprintf(output, 24, "%2$.*1$.99d", 3, 5678);
   fail_unless(rc == 0, "return code should be 0");
+#if defined(__clang__) && \
+  (__clang_major__ > 3 || (__clang_major__ == 3 && __clang_minor__ >= 1))
+#pragma clang diagnostic pop
+#endif
 
   /* 129 input % flags */
   rc = curl_msnprintf(output, 130,
@@ -109,7 +118,7 @@ static CURLcode test_unit1398(const char *arg)
                       "%s%s%s%s%s%s%s%s%s%s" /* 100 */
                       "%s%s%s%s%s%s%s%s%s%s" /* 110 */
                       "%s%s%s%s%s%s%s%s%s%s" /* 120 */
-                      "%s%s%s%s%s%s%s%s%s", /* 129 */
+                      "%s%s%s%s%s%s%s%s%s",  /* 129 */
 
                       "a", "", "", "", "", "", "", "", "", "", /* 10 */
                       "b", "", "", "", "", "", "", "", "", "", /* 20 */
@@ -123,8 +132,8 @@ static CURLcode test_unit1398(const char *arg)
                       "j", "", "", "", "", "", "", "", "", "", /* 100 */
                       "k", "", "", "", "", "", "", "", "", "", /* 110 */
                       "l", "", "", "", "", "", "", "", "", "", /* 120 */
-                      "m", "", "", "", "", "", "", "", ""  /* 129 */
-    );
+                      "m", "", "", "", "", "", "", "", ""      /* 129 */
+  );
   fail_unless(rc == 0, "return code should be 0");
 
   /* 128 input % flags */
@@ -141,7 +150,7 @@ static CURLcode test_unit1398(const char *arg)
                       "%s%s%s%s%s%s%s%s%s%s" /* 100 */
                       "%s%s%s%s%s%s%s%s%s%s" /* 110 */
                       "%s%s%s%s%s%s%s%s%s%s" /* 120 */
-                      "%s%s%s%s%s%s%s%s", /* 128 */
+                      "%s%s%s%s%s%s%s%s",    /* 128 */
 
                       "a", "", "", "", "", "", "", "", "", "", /* 10 */
                       "b", "", "", "", "", "", "", "", "", "", /* 20 */
@@ -155,8 +164,8 @@ static CURLcode test_unit1398(const char *arg)
                       "j", "", "", "", "", "", "", "", "", "", /* 100 */
                       "k", "", "", "", "", "", "", "", "", "", /* 110 */
                       "l", "", "", "", "", "", "", "", "", "", /* 120 */
-                      "m", "", "", "", "", "", "", ""  /* 128 */
-    );
+                      "m", "", "", "", "", "", "", ""          /* 128 */
+  );
   fail_unless(rc == 13, "return code should be 13");
 
   /* 129 output segments */
@@ -167,8 +176,8 @@ static CURLcode test_unit1398(const char *arg)
                       "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" /* 80 */
                       "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" /* 100 */
                       "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" /* 120 */
-                      "%%%%%%%%%%%%%%%%%%" /* 129 */
-    );
+                      "%%%%%%%%%%%%%%%%%%"                       /* 129 */
+  );
   fail_unless(rc == 0, "return code should be 0");
 
   /* 128 output segments */
@@ -179,8 +188,8 @@ static CURLcode test_unit1398(const char *arg)
                       "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" /* 80 */
                       "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" /* 100 */
                       "%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%" /* 120 */
-                      "%%%%%%%%%%%%%%%%" /* 128 */
-    );
+                      "%%%%%%%%%%%%%%%%"                         /* 128 */
+  );
   fail_unless(rc == 128, "return code should be 128");
 
   UNITTEST_END_SIMPLE
